style "gtk-default-el" {
       fontset = "-*-helvetica-medium-r-normal--12-*-*-*-*-*-iso8859-1,\
		  -*-arial-medium-r-normal--12-*-*-*-*-*-iso8859-1,\
		  -*-helvetica-medium-r-normal--12-*-*-*-*-*-iso8859-7,\
		  -*-arial-medium-r-normal--12-*-*-*-*-*-iso8859-7,*-r-*"
}
class "GtkWidget" style "gtk-default-el"

