( cd etc/gtk ; rm -rf gtkrc.bg )
( cd etc/gtk ; ln -sf gtkrc.cp1251 gtkrc.bg )
( cd etc/gtk ; rm -rf gtkrc.be )
( cd etc/gtk ; ln -sf gtkrc.cp1251 gtkrc.be )
( cd etc/gtk ; rm -rf gtkrc.vi )
( cd etc/gtk ; ln -sf gtkrc.vi_VN.tcvn gtkrc.vi )
( cd etc/gtk ; rm -rf gtkrc.vi_VN.viscii111 )
( cd etc/gtk ; ln -sf gtkrc.vi_VN.viscii gtkrc.vi_VN.viscii111 )
( cd etc/gtk ; rm -rf gtkrc.ka )
( cd etc/gtk ; ln -sf gtkrc.ka_GE.georgianps gtkrc.ka )
( cd etc/gtk ; rm -rf gtkrc.et )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-15 gtkrc.et )
( cd etc/gtk ; rm -rf gtkrc.ga )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-14 gtkrc.ga )
( cd etc/gtk ; rm -rf gtkrc.cy )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-14 gtkrc.cy )
( cd etc/gtk ; rm -rf gtkrc.lv )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-13 gtkrc.lv )
( cd etc/gtk ; rm -rf gtkrc.lt )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-13 gtkrc.lt )
( cd etc/gtk ; rm -rf gtkrc.mi )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-13 gtkrc.mi )
( cd etc/gtk ; rm -rf gtkrc.yi )
( cd etc/gtk ; ln -sf gtkrc.cp1255 gtkrc.yi )
( cd etc/gtk ; rm -rf gtkrc.he_IL.microsoftcp1255 )
( cd etc/gtk ; ln -sf gtkrc.cp1255 gtkrc.he_IL.microsoftcp1255 )
( cd etc/gtk ; rm -rf gtkrc.he_IL.cp1255 )
( cd etc/gtk ; ln -sf gtkrc.cp1255 gtkrc.he_IL.cp1255 )
( cd etc/gtk ; rm -rf gtkrc.ru_RU.iso88595 )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-5 gtkrc.ru_RU.iso88595 )
( cd etc/gtk ; rm -rf gtkrc.sp )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-5 gtkrc.sp )
( cd etc/gtk ; rm -rf gtkrc.mk )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-5 gtkrc.mk )
( cd etc/gtk ; rm -rf gtkrc.bg_BG.iso88595 )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-5 gtkrc.bg_BG.iso88595 )
( cd etc/gtk ; rm -rf gtkrc.sr )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-2 gtkrc.sr )
( cd etc/gtk ; rm -rf gtkrc.sq )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-2 gtkrc.sq )
( cd etc/gtk ; rm -rf gtkrc.sl )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-2 gtkrc.sl )
( cd etc/gtk ; rm -rf gtkrc.sk )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-2 gtkrc.sk )
( cd etc/gtk ; rm -rf gtkrc.ro )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-2 gtkrc.ro )
( cd etc/gtk ; rm -rf gtkrc.pl )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-2 gtkrc.pl )
( cd etc/gtk ; rm -rf gtkrc.hu )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-2 gtkrc.hu )
( cd etc/gtk ; rm -rf gtkrc.hr )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-2 gtkrc.hr )
( cd etc/gtk ; rm -rf gtkrc.cs )
( cd etc/gtk ; ln -sf gtkrc.iso-8859-2 gtkrc.cs )
( cd usr/lib64 ; rm -rf libgtk.so )
( cd usr/lib64 ; ln -sf libgtk-1.2.so.0.9.1 libgtk.so )
( cd usr/lib64 ; rm -rf libgtk-1.2.so.0 )
( cd usr/lib64 ; ln -sf libgtk-1.2.so.0.9.1 libgtk-1.2.so.0 )
( cd usr/lib64 ; rm -rf libgdk.so )
( cd usr/lib64 ; ln -sf libgdk-1.2.so.0.9.1 libgdk.so )
( cd usr/lib64 ; rm -rf libgdk-1.2.so.0 )
( cd usr/lib64 ; ln -sf libgdk-1.2.so.0.9.1 libgdk-1.2.so.0 )
