/* type macros, generated by maketypes.awk */

extern GtkType GTK_TYPE_ACCEL_FLAGS;
extern GtkType GTK_TYPE_CALENDAR_DISPLAY_OPTIONS;
extern GtkType GTK_TYPE_CELL_TYPE;
extern GtkType GTK_TYPE_CLIST_DRAG_POS;
extern GtkType GTK_TYPE_BUTTON_ACTION;
extern GtkType GTK_TYPE_CTREE_POS;
extern GtkType GTK_TYPE_CTREE_LINE_STYLE;
extern GtkType GTK_TYPE_CTREE_EXPANDER_STYLE;
extern GtkType GTK_TYPE_CTREE_EXPANSION_TYPE;
extern GtkType GTK_TYPE_DEBUG_FLAG;
extern GtkType GTK_TYPE_DEST_DEFAULTS;
extern GtkType GTK_TYPE_TARGET_FLAGS;
extern GtkType GTK_TYPE_ARROW_TYPE;
extern GtkType GTK_TYPE_ATTACH_OPTIONS;
extern GtkType GTK_TYPE_BUTTON_BOX_STYLE;
extern GtkType GTK_TYPE_CURVE_TYPE;
extern GtkType GTK_TYPE_DIRECTION_TYPE;
extern GtkType GTK_TYPE_JUSTIFICATION;
extern GtkType GTK_TYPE_MATCH_TYPE;
extern GtkType GTK_TYPE_MENU_DIRECTION_TYPE;
extern GtkType GTK_TYPE_MENU_FACTORY_TYPE;
extern GtkType GTK_TYPE_METRIC_TYPE;
extern GtkType GTK_TYPE_ORIENTATION;
extern GtkType GTK_TYPE_CORNER_TYPE;
extern GtkType GTK_TYPE_PACK_TYPE;
extern GtkType GTK_TYPE_PATH_PRIORITY_TYPE;
extern GtkType GTK_TYPE_PATH_TYPE;
extern GtkType GTK_TYPE_POLICY_TYPE;
extern GtkType GTK_TYPE_POSITION_TYPE;
extern GtkType GTK_TYPE_PREVIEW_TYPE;
extern GtkType GTK_TYPE_RELIEF_STYLE;
extern GtkType GTK_TYPE_RESIZE_MODE;
extern GtkType GTK_TYPE_SIGNAL_RUN_TYPE;
extern GtkType GTK_TYPE_SCROLL_TYPE;
extern GtkType GTK_TYPE_SELECTION_MODE;
extern GtkType GTK_TYPE_SHADOW_TYPE;
extern GtkType GTK_TYPE_STATE_TYPE;
extern GtkType GTK_TYPE_SUBMENU_DIRECTION;
extern GtkType GTK_TYPE_SUBMENU_PLACEMENT;
extern GtkType GTK_TYPE_TOOLBAR_STYLE;
extern GtkType GTK_TYPE_TROUGH_TYPE;
extern GtkType GTK_TYPE_UPDATE_TYPE;
extern GtkType GTK_TYPE_VISIBILITY;
extern GtkType GTK_TYPE_WINDOW_POSITION;
extern GtkType GTK_TYPE_WINDOW_TYPE;
extern GtkType GTK_TYPE_SORT_TYPE;
extern GtkType GTK_TYPE_FONT_METRIC_TYPE;
extern GtkType GTK_TYPE_FONT_TYPE;
extern GtkType GTK_TYPE_FONT_FILTER_TYPE;
extern GtkType GTK_TYPE_OBJECT_FLAGS;
extern GtkType GTK_TYPE_ARG_FLAGS;
extern GtkType GTK_TYPE_PACKER_OPTIONS;
extern GtkType GTK_TYPE_SIDE_TYPE;
extern GtkType GTK_TYPE_ANCHOR_TYPE;
extern GtkType GTK_TYPE_PRIVATE_FLAGS;
extern GtkType GTK_TYPE_PROGRESS_BAR_STYLE;
extern GtkType GTK_TYPE_PROGRESS_BAR_ORIENTATION;
extern GtkType GTK_TYPE_RC_FLAGS;
extern GtkType GTK_TYPE_RC_TOKEN_TYPE;
extern GtkType GTK_TYPE_SPIN_BUTTON_UPDATE_POLICY;
extern GtkType GTK_TYPE_SPIN_TYPE;
extern GtkType GTK_TYPE_TOOLBAR_CHILD_TYPE;
extern GtkType GTK_TYPE_TOOLBAR_SPACE_STYLE;
extern GtkType GTK_TYPE_TREE_VIEW_MODE;
extern GtkType GTK_TYPE_FUNDAMENTAL_TYPE;
extern GtkType GTK_TYPE_WIDGET_FLAGS;
extern GtkType GTK_TYPE_GDK_WINDOW_TYPE;
extern GtkType GTK_TYPE_GDK_WINDOW_CLASS;
extern GtkType GTK_TYPE_GDK_IMAGE_TYPE;
extern GtkType GTK_TYPE_GDK_VISUAL_TYPE;
extern GtkType GTK_TYPE_GDK_FONT_TYPE;
extern GtkType GTK_TYPE_GDK_WINDOW_ATTRIBUTES_TYPE;
extern GtkType GTK_TYPE_GDK_WINDOW_HINTS;
extern GtkType GTK_TYPE_GDK_FUNCTION;
extern GtkType GTK_TYPE_GDK_FILL;
extern GtkType GTK_TYPE_GDK_FILL_RULE;
extern GtkType GTK_TYPE_GDK_LINE_STYLE;
extern GtkType GTK_TYPE_GDK_CAP_STYLE;
extern GtkType GTK_TYPE_GDK_JOIN_STYLE;
extern GtkType GTK_TYPE_GDK_CURSOR_TYPE;
extern GtkType GTK_TYPE_GDK_FILTER_RETURN;
extern GtkType GTK_TYPE_GDK_VISIBILITY_STATE;
extern GtkType GTK_TYPE_GDK_EVENT_TYPE;
extern GtkType GTK_TYPE_GDK_EVENT_MASK;
extern GtkType GTK_TYPE_GDK_NOTIFY_TYPE;
extern GtkType GTK_TYPE_GDK_CROSSING_MODE;
extern GtkType GTK_TYPE_GDK_MODIFIER_TYPE;
extern GtkType GTK_TYPE_GDK_SUBWINDOW_MODE;
extern GtkType GTK_TYPE_GDK_INPUT_CONDITION;
extern GtkType GTK_TYPE_GDK_STATUS;
extern GtkType GTK_TYPE_GDK_BYTE_ORDER;
extern GtkType GTK_TYPE_GDK_GC_VALUES_MASK;
extern GtkType GTK_TYPE_GDK_SELECTION;
extern GtkType GTK_TYPE_GDK_PROPERTY_STATE;
extern GtkType GTK_TYPE_GDK_PROP_MODE;
extern GtkType GTK_TYPE_GDK_INPUT_SOURCE;
extern GtkType GTK_TYPE_GDK_INPUT_MODE;
extern GtkType GTK_TYPE_GDK_AXIS_USE;
extern GtkType GTK_TYPE_GDK_TARGET;
extern GtkType GTK_TYPE_GDK_SELECTION_TYPE;
extern GtkType GTK_TYPE_GDK_EXTENSION_MODE;
extern GtkType GTK_TYPE_GDK_IM_STYLE;
extern GtkType GTK_TYPE_GDK_IC_ATTRIBUTES_TYPE;
extern GtkType GTK_TYPE_GDK_WM_DECORATION;
extern GtkType GTK_TYPE_GDK_WM_FUNCTION;
extern GtkType GTK_TYPE_GDK_COLOR_CONTEXT_MODE;
extern GtkType GTK_TYPE_GDK_OVERLAP_TYPE;
extern GtkType GTK_TYPE_GDK_DRAG_ACTION;
extern GtkType GTK_TYPE_GDK_DRAG_PROTOCOL;
extern GtkType GTK_TYPE_GDK_RGB_DITHER;
extern GtkType GTK_TYPE_ACCEL_GROUP;
extern GtkType GTK_TYPE_SELECTION_DATA;
extern GtkType GTK_TYPE_STYLE;
extern GtkType GTK_TYPE_CTREE_NODE;
extern GtkType GTK_TYPE_GDK_COLORMAP;
extern GtkType GTK_TYPE_GDK_VISUAL;
extern GtkType GTK_TYPE_GDK_FONT;
extern GtkType GTK_TYPE_GDK_WINDOW;
extern GtkType GTK_TYPE_GDK_DRAG_CONTEXT;
extern GtkType GTK_TYPE_GDK_EVENT;
extern GtkType GTK_TYPE_GDK_COLOR;

#define	GTK_TYPE_NUM_BUILTINS	(121)
